@@ -123,17 +123,21 @@ class DataSource:
         experiment_slug,
         from_expr_dataset=None,
         analysis_basis=AnalysisBasis.ENROLLMENTS,
+        exposure_signal=None,
     ):
         """Return a nearly-self contained SQL query.
 
         This query does not define ``enrollments`` but otherwise could
         be executed to query all metrics from this data source.
         """
-        return """SELECT
+        return """
+        SELECT
             e.client_id,
             e.branch,
             e.analysis_window_start,
             e.analysis_window_end,
+            e.num_exposure_events,
+            e.exposure_date,
             {metrics}
         FROM enrollments e
             LEFT JOIN {from_expr} ds
@@ -146,6 +150,8 @@ class DataSource:
         GROUP BY
             e.client_id,
             e.branch,
+            e.num_exposure_events,
+            e.exposure_date,
             e.analysis_window_start,
             e.analysis_window_end""".format(
             client_id=self.client_id_column,
@@ -160,7 +166,7 @@ class DataSource:
                 for m in metric_list
             ),
             date="exposure_date"
-            if analysis_basis == AnalysisBasis.EXPOSURES
+            if analysis_basis == AnalysisBasis.EXPOSURES and exposure_signal is None
             else "enrollment_date",
             ignore_pre_enroll_first_day=self.experiments_column_expr.format(
                 submission_date=self.submission_date_column,
